@@ -1,12 +1,12 @@
 from typer import Option as Opt
 from ..system import system
 from .main import program
-from .. import config
+from .. import settings
 
 
 @program.command(name="api")
 def program_api(
-    port: int = Opt(config.DEFAULT_SERVER_PORT, help="Specify server port"),
+    port: int = Opt(settings.DEFAULT_SERVER_PORT, help="Specify server port"),
 ):
     """
     Start API server
