@@ -14,14 +14,13 @@ from .header import Header
 from .system import system
 from .field import Field
 from .row import Row
+from . import settings
 from . import helpers
 from . import errors
-from . import config
 
 
 # NOTE:
-# Consider making resource.stats unavailable until it's fully calculated
-# Also, review the situation with describe function removing stats (move to infer?)
+# Review the situation with describe function removing stats (move to infer?)
 
 
 class Resource(Metadata):
@@ -249,7 +248,7 @@ class Resource(Metadata):
             if value:
                 if name == "hash":
                     hashing, value = helpers.parse_resource_hash(value)
-                    if hashing != config.DEFAULT_HASHING:
+                    if hashing != settings.DEFAULT_HASHING:
                         self["hashing"] = hashing
                 self.setdefault("stats", {})
                 self["stats"][name] = value
@@ -310,7 +309,7 @@ class Resource(Metadata):
         Returns
             str: resource title
         """
-        return self.get("title")
+        return self.get("title", "")
 
     @Metadata.property
     def description(self):
@@ -318,7 +317,23 @@ class Resource(Metadata):
         Returns
             str: resource description
         """
-        return self.get("description")
+        return self.get("description", "")
+
+    @Metadata.property(cache=False, write=False)
+    def description_html(self):
+        """
+        Returns:
+            str?: resource description
+        """
+        return helpers.md_to_html(self.description)
+
+    @Metadata.property
+    def description_text(self):
+        """
+        Returns:
+            str: resource description
+        """
+        return helpers.html_to_text(self.description_html)
 
     @Metadata.property
     def mediatype(self):
@@ -326,7 +341,7 @@ class Resource(Metadata):
         Returns
             str: resource mediatype
         """
-        return self.get("mediatype")
+        return self.get("mediatype", "")
 
     @Metadata.property
     def licenses(self):
@@ -334,7 +349,8 @@ class Resource(Metadata):
         Returns
             dict[]: resource licenses
         """
-        return self.get("licenses")
+        licenses = self.get("licenses", [])
+        return self.metadata_attach("licenses", licenses)
 
     @Metadata.property
     def sources(self):
@@ -342,24 +358,25 @@ class Resource(Metadata):
         Returns
             dict[]: resource sources
         """
-        return self.get("sources")
+        sources = self.get("sources", [])
+        return self.metadata_attach("sources", sources)
 
     @Metadata.property
     def profile(self):
         """
         Returns
-            str?: resource profile
+            str: resource profile
         """
-        default = config.DEFAULT_RESOURCE_PROFILE
+        default = settings.DEFAULT_RESOURCE_PROFILE
         if self.tabular:
-            default = config.DEFAULT_TABULAR_RESOURCE_PROFILE
+            default = settings.DEFAULT_TABULAR_RESOURCE_PROFILE
         return self.get("profile", default)
 
     @Metadata.property
     def path(self):
         """
         Returns
-            str?: resource path
+            str: resource path
         """
         return self.get("path", self.__file.path)
 
@@ -375,15 +392,21 @@ class Resource(Metadata):
     def scheme(self):
         """
         Returns
-            str?: resource scheme
+            str: resource scheme
         """
-        return self.get("scheme", self.__file.scheme).lower()
+        scheme = self.get("scheme", self.__file.scheme).lower()
+        # NOTE: review this approach (see #991)
+        # NOTE: move to plugins.multipart when plugin.priority/create_resource is implemented
+        if self.multipart and scheme != "multipart":
+            note = f'Multipart resource requires "multipart" scheme but "{scheme}" is set'
+            raise FrictionlessException(errors.SchemeError(note=note))
+        return scheme
 
     @Metadata.property
     def format(self):
         """
         Returns
-            str?: resource format
+            str: resource format
         """
         return self.get("format", self.__file.format).lower()
 
@@ -391,23 +414,23 @@ class Resource(Metadata):
     def hashing(self):
         """
         Returns
-            str?: resource hashing
+            str: resource hashing
         """
-        return self.get("hashing", config.DEFAULT_HASHING).lower()
+        return self.get("hashing", settings.DEFAULT_HASHING).lower()
 
     @Metadata.property
     def encoding(self):
         """
         Returns
-            str?: resource encoding
+            str: resource encoding
         """
-        return self.get("encoding", config.DEFAULT_ENCODING).lower()
+        return self.get("encoding", settings.DEFAULT_ENCODING).lower()
 
     @Metadata.property
     def innerpath(self):
         """
         Returns
-            str?: resource compression path
+            str: resource compression path
         """
         return self.get("innerpath", self.__file.innerpath)
 
@@ -415,7 +438,7 @@ class Resource(Metadata):
     def compression(self):
         """
         Returns
-            str?: resource compression
+            str: resource compression
         """
         return self.get("compression", self.__file.compression).lower()
 
@@ -423,7 +446,7 @@ class Resource(Metadata):
     def control(self):
         """
         Returns
-            Control?: resource control
+            Control: resource control
         """
         control = self.get("control")
         if control is None:
@@ -439,7 +462,7 @@ class Resource(Metadata):
     def dialect(self):
         """
         Returns
-            Dialect?: resource dialect
+            Dialect: resource dialect
         """
         dialect = self.get("dialect")
         if dialect is None:
@@ -455,7 +478,7 @@ class Resource(Metadata):
     def layout(self):
         """
         Returns:
-            Layout?: table layout
+            Layout: table layout
         """
         layout = self.get("layout")
         if layout is None:
@@ -481,11 +504,14 @@ class Resource(Metadata):
             schema = self.metadata_attach("schema", schema)
         return schema
 
+    # NOTE: updating this Metadata.propertyc reates a huge overheader
+    # Once it's fixed we might return to stats updating during reading
+    # See: https://github.com/frictionlessdata/frictionless-py/issues/879
     @Metadata.property
     def stats(self):
         """
         Returns
-            dict?: resource stats
+            dict: resource stats
         """
         stats = self.get("stats")
         if stats is None:
@@ -909,7 +935,6 @@ class Resource(Metadata):
 
                 # Create row
                 self.__row_number += 1
-                self.stats["rows"] = self.__row_number
                 row = Row(
                     cells,
                     field_info=field_info,
@@ -956,7 +981,15 @@ class Resource(Metadata):
                                 continue
                             match = cells in group_lookup.get(group["sourceKey"], set())
                             if not match:
-                                note = "not found in the lookup table"
+                                note = (
+                                    'for "%s": values "%s" not found in the lookup table "%s" as "%s"'
+                                    % (
+                                        ", ".join(group["targetKey"]),
+                                        ", ".join(str(d) for d in cells),
+                                        group["sourceName"],
+                                        ", ".join(group["sourceKey"]),
+                                    )
+                                )
                                 error = errors.ForeignKeyError.from_row(row, note=note)
                                 row.errors.append(error)
 
@@ -971,6 +1004,9 @@ class Resource(Metadata):
                 # Yield row
                 yield row
 
+            # Update stats
+            self.stats["rows"] = self.__row_number
+
         # Return row stream
         return row_stream()
 
@@ -1185,7 +1221,7 @@ class Resource(Metadata):
 
     metadata_duplicate = True
     metadata_Error = errors.ResourceError
-    metadata_profile = deepcopy(config.RESOURCE_PROFILE)
+    metadata_profile = deepcopy(settings.RESOURCE_PROFILE)
     metadata_profile["properties"]["control"] = {"type": ["string", "object"]}
     metadata_profile["properties"]["dialect"] = {"type": ["string", "object"]}
     metadata_profile["properties"]["layout"] = {"type": ["string", "object"]}
